@@ -986,11 +986,11 @@ def test_get_routes():
 
 
 @httpretty.activate
-def test_get_vehicles():
+def test_get_real_time_vehicles():
     agency = "test_agency"
     client = SwiftlyAPIClient(agency_key=agency, api_key="test_api_key")
 
-    mock_url = client._format_url(client.VEHICLES)
+    mock_url = client._format_url(client.REAL_TIME_VEHICLES)
 
     httpretty.register_uri(
         httpretty.GET,
@@ -1050,7 +1050,62 @@ def test_get_vehicles():
         ],
     )
 
-    vehicles = client.get_vehicles()
+    vehicles = client.get_real_time_vehicles()
     vehicle_ids = [vehicle["id"] for vehicle in vehicles]
 
-    assert vehicle_ids == ["0402", "0523"]
\ No newline at end of file
+    assert vehicle_ids == ["0402", "0523"]
+
+
+@httpretty.activate
+def test_get_vehicles():
+    agency = "test_agency"
+    client = SwiftlyAPIClient(agency_key=agency, api_key="test_api_key")
+
+    mock_url = client._format_url(client.VEHICLES)
+
+    httpretty.register_uri(
+        httpretty.GET,
+        mock_url,
+        responses=[
+            httpretty.Response(
+                body="""
+                    [
+                        {
+                            "id": 83900,
+                            "externalId": "0096",
+                            "vehicleGroupId": 146,
+                            "vehicleType": null,
+                            "nonPassenger": false,
+                            "hasOa": false,
+                            "capacity": null,
+                            "crushCapacity": null,
+                            "createdAt": "2022-10-05T00:12:00.285394Z",
+                            "updatedAt": "2022-10-05T00:12:00.285394Z",
+                            "lastReported": null,
+                            "devicesUpdatedAt": null
+                        },
+                        {
+                            "id": 83902,
+                            "externalId": "0101",
+                            "vehicleGroupId": 146,
+                            "vehicleType": null,
+                            "nonPassenger": false,
+                            "hasOa": false,
+                            "capacity": null,
+                            "crushCapacity": null,
+                            "createdAt": "2022-10-05T00:12:00.365857Z",
+                            "updatedAt": "2022-10-05T00:12:00.365857Z",
+                            "lastReported": null,
+                            "devicesUpdatedAt": null
+                        }
+                    ]
+                    """,
+                status=200,
+            ),
+        ],
+    )
+
+    vehicles = client.get_vehicles()
+    vehicle_ids = [vehicle["externalId"] for vehicle in vehicles]
+
+    assert vehicle_ids == ["0096", "0101"]
\ No newline at end of file
